Struct NumericalFor

pub struct NumericalFor<'a> {
    pub for_: TokenReference<'a>,
    pub name: Name<'a>,
    pub assign: TokenReference<'a>,
    pub from: Box<Expr<'a>>,
    pub comma: TokenReference<'a>,
    pub to: Box<Expr<'a>>,
    pub step: Option<(TokenReference<'a>, Box<Expr<'a>>)>,
    pub do_: TokenReference<'a>,
    pub block: Box<Block<'a>>,
    pub end: TokenReference<'a>,
}
A numerical for loop:

for name = from, to, step do
  ...
end

Fields

for_: TokenReference<'a>

A reference to the Symbol::For token.

name: Name<'a>

The loop variable name.

assign: TokenReference<'a>

A reference to the Symbol::Assign token.

from: Box<Expr<'a>>

The initial value.

comma: TokenReference<'a>

A reference to the Symbol::Comma token that follows the initial value expression.

to: Box<Expr<'a>>

The end value.

step: Option<(TokenReference<'a>, Box<Expr<'a>>)>

A reference to the Symbol::Comma token that follows the end value expression, as well as the expression that evaluates to the increment step.

do_: TokenReference<'a>

A reference to the Symbol::Do token.

block: Box<Block<'a>>

The body loop.

end: TokenReference<'a>

A reference to the Symbol::End token.