pub trait HasSpan {
// Required method
fn span(&self) -> Span;
}Expand description
A trait implemented by types that have a Span associated with them.
pub trait HasSpan {
// Required method
fn span(&self) -> Span;
}A trait implemented by types that have a Span associated with them.